--=============================================================================
-- File:	CH_Help.lua
-- Author:	rudy
-- Description:	Help pages and config
--=============================================================================

local gFriendHPLabelOptions = {PERCENT       = CHHT_FRIEND_HP_LABEL_PERCENT,
                               PERCENT_SIGN  = CHHT_FRIEND_HP_LABEL_PERCENT_SIGN,
                               CURRENT       = CHHT_FRIEND_HP_LABEL_CURRENT,
                               MISSING       = CHHT_FRIEND_HP_LABEL_MISSING};
local gPartyLabelOptions     = {CLASS = CHHT_FRIEND_PARTY_LABEL_CLASS,
                                NAME  = CHHT_FRIEND_PARTY_LABEL_NAME,
                                BOTH  = CHHT_FRIEND_PARTY_LABEL_BOTH,
                                COLOR = CHHT_FRIEND_PARTY_LABEL_COLOR};
local gFriendDebuffsOptions  = {NONE    = CHHT_FRIEND_FRIEND_DEBUFF_NONE,
                                CURABLE = CHHT_FRIEND_FRIEND_DEBUFF_CURABLE,
                                ALL     = CHHT_FRIEND_FRIEND_DEBUFF_ALL};
local gResurrectDruidOptions = {AFTER_COMBAT = CHHT_FRIEND_RESURRECT_AFTER_COMBAT,
                                ALWAYS       = CHHT_FRIEND_RESURRECT_ALWAYS,
                                NEVER        = CHHT_FRIEND_RESURRECT_NEVER};
local gResurrectOtherOptions = {AFTER_COMBAT = CHHT_FRIEND_RESURRECT_AFTER_COMBAT,
                                NEVER        = CHHT_FRIEND_RESURRECT_NEVER};
local gFriendFrameBackgroundOptions = { HEALTH = CHHT_FRIEND_FRAME_BACKGROUND_HEALTH,
                                        CLASS  = CHHT_FRIEND_FRAME_BACKGROUND_CLASS,
                                        BLACK  = CHHT_FRIEND_FRAME_BACKGROUND_BLACK,
                                        TRANS  = CHHT_FRIEND_FRAME_BACKGROUND_TRANS};

-- ============================================================================
--   friend config             
-- ============================================================================

function CHH_FriendInit()

  local playerClass = CH_UnitClass( 'player' );

  CHH_InitTabs( CHH_Friend, CHH_FriendGeneral, 'FRIEND', 'MISC', CHH_FriendInit, nil );

  UIDropDownMenu_Initialize( CHH_FriendGeneralResurrect, CHH_FriendGeneralResurrectInit );
  UIDropDownMenu_Initialize( CHH_FriendGeneralFrameBackground, CHH_FriendGeneralFrameBackgroundInit );
  UIDropDownMenu_Initialize( CHH_FriendGeneralHPLabel, CHH_FriendGeneralHPLabelInit );
  UIDropDownMenu_Initialize( CHH_FriendGeneralPartyLabel, CHH_FriendGeneralPartyLabelInit );
  UIDropDownMenu_Initialize( CHH_FriendGeneralFriendDebuffs, CHH_FriendGeneralFriendDebuffsInit );

  if ( playerClass == 'PRIEST' ) then
    CHH_FriendGeneralFinetuneSpell1Name:SetText( CHHT_FRIEND_POWER_WORD_SHIELD );
    CHH_FriendGeneralFinetuneSpell1:SetChecked( CH_Config.finetunePwS );
    CHH_FriendGeneralFinetuneSpell2Name:SetText( CHHT_FRIEND_RENEW );
    CHH_FriendGeneralFinetuneSpell2:SetChecked( CH_Config.finetuneRenew );
  elseif ( playerClass == 'DRUID' ) then
    CHH_FriendGeneralFinetuneSpell1Name:SetText( CHHT_FRIEND_REGROWTH );
    CHH_FriendGeneralFinetuneSpell1:SetChecked( CH_Config.finetuneRegrowth );
    CHH_FriendGeneralFinetuneSpell2Name:SetText( CHHT_FRIEND_REJUVENATION );
    CHH_FriendGeneralFinetuneSpell2:SetChecked( CH_Config.finetuneRejuvenation );
  else
    CHH_FriendGeneralFinetuneSpell1:Hide();
    CHH_FriendGeneralFinetuneSpell1Name:Hide();
    CHH_FriendGeneralFinetuneSpell2:Hide();
    CHH_FriendGeneralFinetuneSpell2Name:Hide();
  end

end

function CHH_FriendGeneralHPLabelInit( )

  local k, v;
  local info = {};
  local data;

  for k,v in gFriendHPLabelOptions do
    info.text = v;
    if ( k == CH_Config.friendHPLabel ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_FriendGeneralHPLabel );
    else
      info.check = nil;
    end
    info.func = CHH_FriendGeneralHPLabelClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_FriendGeneralHPLabelClicked()

  CH_Config.friendHPLabel = this.value;
  UIDropDownMenu_SetText( gFriendHPLabelOptions[this.value], CHH_FriendGeneralHPLabel );

end

function CHH_FriendGeneralFrameBackgroundInit( )

  local k, v;
  local info = {};
  local data;

  for k,v in gFriendFrameBackgroundOptions do
    info.text = v;
    if ( k == CH_Config.friendFrameBackground ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_FriendGeneralFrameBackground );
    else
      info.check = nil;
    end
    info.func = CHH_FriendGeneralFrameBackgroundClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_FriendGeneralFrameBackgroundClicked()

  CH_Config.friendFrameBackground = this.value;
  UIDropDownMenu_SetText( gFriendFrameBackgroundOptions[this.value], CHH_FriendGeneralFrameBackground );

end

function CHH_FriendGeneralPartyLabelInit()

  local k, v;
  local info = {};

  for k,v in gPartyLabelOptions do
    info.text = v;
    if ( k == CH_Config.partyLabel ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_FriendGeneralPartyLabel );
    else
      info.check = nil;
    end
    info.func = CHH_FriendGeneralPartyLabelClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_FriendGeneralPartyLabelClicked()

  CH_Config.partyLabel = this.value;
  UIDropDownMenu_SetText( gPartyLabelOptions[this.value], CHH_FriendGeneralPartyLabel );

end

function CHH_FriendGeneralFriendDebuffsInit( )

  local k, v;
  local info = {};

  for k,v in gFriendDebuffsOptions do
    info.text = v;
    if ( k == CH_Config.showFriendDebuffs ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_FriendGeneralFriendDebuffs );
    else
      info.check = nil;
    end
    info.func = CHH_FriendGeneralFriendDebuffsClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_FriendGeneralFriendDebuffsClicked()

  CH_Config.showFriendDebuffs = this.value;
  UIDropDownMenu_SetText( gFriendDebuffsOptions[this.value], CHH_FriendGeneralFriendDebuffs );

end

function CHH_FriendGeneralResurrectInit( )

  local k, v;
  local info = {};
  local data;

  if ( CH_UnitClass('player') == 'DRUID' ) then
    data = gResurrectDruidOptions;
  else
    data = gResurrectOtherOptions;
  end

  for k,v in data do
    info.text = v;
    if ( k == CH_Config.resurrectPlayer ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_FriendGeneralResurrect );
    else
      info.check = nil;
    end
    info.func = CHH_FriendGeneralResurrectClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_FriendColorClicked()

  CH_Config.colorTarget = this.value;
  UIDropDownMenu_SetText( gTargetColorOptions[this.value], CHH_FriendColor );

end

function CHH_FriendGeneralResurrectClicked()

  CH_Config.resurrectPlayer = this.value;
  UIDropDownMenu_SetText( gResurrectDruidOptions[this.value], CHH_FriendGeneralResurrect );

end

function CHH_FriendGeneralFinetuneSpell1Clicked()

  local playerClass = CH_UnitClass( 'player' );

  if ( playerClass == 'PRIEST' ) then
    CH_Config.finetunePwS = CH_ToBoolean( this:GetChecked() );
  elseif ( playerClass == 'DRUID' ) then
    CH_Config.finetuneRegrowth = CH_ToBoolean( this:GetChecked() );
  end

end

function CHH_FriendGeneralFinetuneSpell2Clicked()

  local playerClass = CH_UnitClass( 'player' );

  if ( playerClass == 'PRIEST' ) then
    CH_Config.finetuneRenew = CH_ToBoolean( this:GetChecked() );
  elseif ( playerClass == 'DRUID' ) then
    CH_Config.finetuneRejuvenation = CH_ToBoolean( this:GetChecked() );
  end

end
