--=============================================================================
-- File:	CHH_Gui.lua
-- Author:	rudy
-- Description:	Configs for teh GUI
--=============================================================================

local gFrameGroupModeOptions = {ALL=CHHT_GUI_FRAME_GROUP_MODE_ALL,
                                GROUP=CHHT_GUI_FRAME_GROUP_MODE_GROUP};
local gTargetColorOptions    = {NEVER=CHHT_GUI_TARGET_COLOR_NEVER,
                                PLAYER=CHHT_GUI_TARGET_COLOR_PLAYER,
                                ALWAYS=CHHT_GUI_TARGET_COLOR_ALWAYS};
local gTargetDebuffsOptions  = {NONE=CHHT_GUI_TARGET_DEBUFF_NONE,
                                CASTABLE=CHHT_GUI_TARGET_DEBUFF_CASTABLE,
                                ENEMY_CASTABLE=CHHT_GUI_TARGET_DEBUFF_ENEMY_CASTABLE,
                                ENEMY_ALL=CHHT_GUI_TARGET_DEBUFF_ENEMY_ALL,
                                ALL=CHHT_GUI_TARGET_DEBUFF_ALL};
local gFrameAlignVertical    = {LEFT=CHHT_GUI_FRAME_ALIGN_LEFT,
                                CENTER=CHHT_GUI_FRAME_ALIGN_CENTER,
                                RIGHT=CHHT_GUI_FRAME_ALIGN_RIGHT};
local gDockTargetOptions     = {NONE=CHHT_GUI_DOCK_TARGET_NONE,
                                RIGHT=CHHT_GUI_DOCK_TARGET_RIGHT,
                                LEFT=CHHT_GUI_DOCK_TARGET_LEFT};
local gUnitTooltipOptions    = {ALWAYS=CHHT_GUI_UNIT_TOOLTIP_ALWAYS,
                                NEVER=CHHT_GUI_UNIT_TOOLTIP_NEVER,
                                SHIFT=CHHT_GUI_UNIT_TOOLTIP_SHIFT,
                                CTRL=CHHT_GUI_UNIT_TOOLTIP_CTRL,
                                ALT=CHHT_GUI_UNIT_TOOLTIP_ALT,
                                SHIFTCTRL=CHHT_GUI_UNIT_TOOLTIP_SHIFTCTRL,
                                SHIFTALT=CHHT_GUI_UNIT_TOOLTIP_SHIFTALT,
                                CTRLALT=CHHT_GUI_UNIT_TOOLTIP_CTRLALT,
                                SHIFTCTRLATL=CHHT_GUI_UNIT_TOOLTIP_SHIFTCTRLALT};
local gRaidTooltipOptions    = {HIDE=CHHT_GUI_RAID_TOOLTIP_HIDE,
                                LEFT=CHHT_GUI_RAID_TOOLTIP_LEFT,
                                TOP=CHHT_GUI_RAID_TOOLTIP_TOP,
                                RIGHT=CHHT_GUI_RAID_TOOLTIP_RIGHT,
                                BOTTOM=CHHT_GUI_RAID_TOOLTIP_BOTTOM,
                                MAIN=CHHT_GUI_RAID_TOOLTIP_MAIN};
local gActionsTooltipOptions = {ALWAYS=CHHT_GUI_ACTION_TOOLTIP_ALWAYS,
                                NEVER=CHHT_GUI_ACTION_TOOLTIP_NEVER};

-- ============================================================================
--   GUI / Misc
-- ============================================================================

function CHH_GuiMiscTab()

  CHH_InitTabs( CHH_Gui, CHH_GuiMisc, 'GUI', 'MISC', CHH_GuiMiscTab, nil );

  UIDropDownMenu_Initialize( CHH_GuiMiscFrameGroupMode, CHH_GuiMiscFrameGroupModeInit );

  CHH_GuiMiscPartySortInit();

end

function CHH_GuiMiscPartySortInit()

  local line, unit;

  for line,unit in CH_Config.partySort do
    if ( UnitExists(unit) ) then
      getglobal('CHH_GuiMiscPartySortLine'..line..'Unit'):SetText( string.format("%s (%s)",getglobal('CHHT_LABEL_'..strupper(unit)),CH_UnitName(unit)) );
    else
      getglobal('CHH_GuiMiscPartySortLine'..line..'Unit'):SetText( getglobal('CHHT_LABEL_'..strupper(unit)) );
    end
    getglobal('CHH_GuiMiscPartySortLine'..line).lineNo = line;
  end

end

function CHH_GuiMiscPlayerSortButtonUpClicked()

  local lineNo = this:GetParent().lineNo;

  if ( (not lineNo) or lineNo < 2 ) then
    return;
  end

  lineUnit = CH_Config.partySort[lineNo];
  CH_Config.partySort[lineNo] = CH_Config.partySort[lineNo-1];
  CH_Config.partySort[lineNo-1] = lineUnit;

  CHH_GuiMiscPartySortInit();
  CH_AdjustPartyFrames();

end

function CHH_GuiMiscPlayerSortButtonDownClicked()

  local lineNo = this:GetParent().lineNo;

  if ( (not lineNo) or lineNo > 9 ) then
    return;
  end

  lineUnit = CH_Config.partySort[lineNo];
  CH_Config.partySort[lineNo] = CH_Config.partySort[lineNo+1];
  CH_Config.partySort[lineNo+1] = lineUnit;

  CHH_GuiMiscPartySortInit();
  CH_AdjustPartyFrames();

end

function CHH_GuiMiscFrameGroupModeInit()

  local k, v;
  local info = {};

  for k,v in gFrameGroupModeOptions do
    info.text = v;
    if ( k == CH_Config.frameGroupMode ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_GuiMiscFrameGroupMode );
    else
      info.check = nil;
    end
    info.func = CHH_GuiMiscFrameGroupModeClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_GuiMiscFrameGroupModeClicked()

  CH_ConfigSetOption( 'frameGroupMode', this.value );
  UIDropDownMenu_SetText( gFrameGroupModeOptions[this.value], CHH_GuiMiscFrameGroupMode );

end

-- ============================================================================
--   GUI / Raid
-- ============================================================================

function CHH_GuiRaidTab()

  CHH_InitTabs( CHH_Gui, CHH_GuiRaid, 'GUI', 'RAID', CHH_GuiRaidTab, nil );

end

-- ============================================================================
--   GUI / Basic Frames
-- ============================================================================

function CHH_GuiBasicTab()

  CHH_InitTabs( CHH_Gui, CHH_GuiBasic, 'GUI', 'MAIN_FRAME', CHH_GuiBasicTab, nil );

  UIDropDownMenu_Initialize( CHH_GuiBasicFrameAlign, CHH_GuiBasicFrameAlignInit );

end

function CHH_GuiBasicFrameAlignInit()

  local k, v;
  local info = {};

  for k,v in gFrameAlignVertical do
    info.text = v;
    if ( k == CH_Config.frameAlign ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_GuiBasicFrameAlign );
    else
      info.check = nil;
    end
    info.func = CHH_GuiBasicFrameAlignClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_GuiBasicFrameAlignClicked()

  CH_Config.frameAlign = this.value;
  UIDropDownMenu_SetText( gFrameAlignVertical[this.value], CHH_GuiBasicFrameAlign );

  CH_AdjustPartyFrames( );

end

-- ============================================================================
--   GUI / Target Frames
-- ============================================================================

function CHH_GuiTargetTab()

  CHH_InitTabs( CHH_Gui, CHH_GuiTarget, 'GUI', 'TARGET_FRAME', CHH_GuiTargetTab, nil );

  UIDropDownMenu_Initialize( CHH_GuiTargetDockTarget, CHH_GuiTargetDockTargetInit );
  UIDropDownMenu_Initialize( CHH_GuiTargetColor, CHH_GuiTargetColorInit );
  UIDropDownMenu_Initialize( CHH_GuiTargetDebuffs, CHH_GuiTargetDebuffsInit )

end

function CHH_GuiTargetDockTargetInit()

  local k, v;
  local info = {};

  for k,v in gDockTargetOptions do
    info.text = v;
    if ( k == CH_Config.dockTarget ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_GuiTargetDockTarget );
    else
      info.check = nil;
    end
    info.func = CHH_GuiTargetDockTargetClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_GuiTargetDockTargetClicked()

  CH_Config.dockTarget = this.value;
  UIDropDownMenu_SetText( gDockTargetOptions[this.value], CHH_GuiTargetDockTarget );

  CH_DockTargetFrames();

end

function CHH_GuiTargetDebuffsInit( )

  local k, v;
  local info = {};

  for k,v in gTargetDebuffsOptions do
    info.text = v;
    if ( k == CH_Config.showTargetDebuffs ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_GuiTargetDebuffs );
    else
      info.check = nil;
    end
    info.func = CHH_GuiTargetDebuffsClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_GuiTargetDebuffsClicked()

  CH_Config.showTargetDebuffs = this.value;
  UIDropDownMenu_SetText( gTargetDebuffsOptions[this.value], CHH_GuiTargetDebuffs );

end

function CHH_GuiTargetColorInit( )

  local k, v;
  local info = {};

  for k,v in gTargetColorOptions do
    info.text = v;
    if ( k == CH_Config.colorTarget ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_GuiTargetColor );
    else
      info.check = nil;
    end
    info.func = CHH_GuiTargetColorClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_GuiTargetColorClicked()

  CH_Config.colorTarget = this.value;
  UIDropDownMenu_SetText( gTargetColorOptions[this.value], CHH_GuiTargetColor );

end

-- ============================================================================
--   GUI / Tooltips
-- ============================================================================

function CHH_GuiTooltipTab()

  CHH_InitTabs( CHH_Gui, CHH_GuiTooltip, 'GUI', 'TOOLTIP', CHH_GuiTooltipTab, nil );

  UIDropDownMenu_Initialize( CHH_GuiTooltipTooltips, CHH_GuiTooltipTooltipsInit );
  UIDropDownMenu_Initialize( CHH_GuiTooltipRaidTooltips, CHH_GuiTooltipRaidTooltipsInit );
  UIDropDownMenu_Initialize( CHH_GuiTooltipActionsTooltips, CHH_GuiTooltipActionsTooltipsInit );

end

function CHH_GuiTooltipTooltipsInit()

  local k, v;
  local info = {};
  for k,v in gUnitTooltipOptions do
    info.text = v;
    if ( k == CH_Config.unitTooltipInfo ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_GuiTooltipTooltips );
    else
      info.check = nil;
    end
    info.func = CHH_GuiTooltipTooltipsClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_GuiTooltipTooltipsClicked()

  CH_Config.unitTooltipInfo = this.value;
  UIDropDownMenu_SetText( gUnitTooltipOptions[this.value], CHH_GuiTooltipTooltips );

end

function CHH_GuiTooltipRaidTooltipsInit()

  local k, v;
  local info = {};

  for k,v in gRaidTooltipOptions do
    info.text = v;
    if ( k == CH_Config.raidTooltipInfo ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_GuiTooltipRaidTooltips );
    else
      info.check = nil;
    end
    info.func = CHH_GuiTooltipRaidTooltipsClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_GuiTooltipRaidTooltipsClicked()

  CH_Config.raidTooltipInfo = this.value;
  UIDropDownMenu_SetText( gRaidTooltipOptions[this.value], CHH_GuiTooltipRaidTooltips );

end

function CHH_GuiTooltipActionsTooltipsInit()

  local k, v;
  local info = {};

  for k,v in gActionsTooltipOptions do
    info.text = v;
    if ( k == CH_Config.actionsTooltipInfo ) then
      info.check = nil;
      UIDropDownMenu_SetText( v, CHH_GuiTooltipActionsTooltips );
    else
      info.check = nil;
    end
    info.func = CHH_GuiTooltipActionsTooltipsClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_GuiTooltipActionsTooltipsClicked()

  CH_Config.actionsTooltipInfo = this.value;
  UIDropDownMenu_SetText( gActionsTooltipOptions[this.value], CHH_GuiTooltipActionsTooltips );

end
