--=============================================================================
-- File:	CH_Help.lua
-- Author:	rudy
-- Description:	Help pages and config
--=============================================================================

local gPanicHeadings = {Heal = CHHT_PANIC_TITLE_HEAL,
                        Buff = CHHT_PANIC_TITLE_BUFF};
local gPanicBehavior = {FULL  = CHHT_PANIC_TITLE_FULL,
                        TRASH = CHHT_PANIC_TITLE_TRASH};

local gEmergencyMapping = {[1] = 'None', [2] = 'Wounded', [3] = 'Fair', [4] = 'Poor', [5] = 'Critic'}

local gPanicBehaviorClass = 'DRUID';
local gPanicBehaviorEmergency = CH_EMERGENCY_NONE;

function CHH_PanicInit()

  local panicType, panicTitle, unit;

  for panicType,panicTitle in gPanicHeadings do
    getglobal('CHH_PanicGeneralPanic'..panicType..'TitleText'):SetText( panicTitle );
    for _,unit in {'Player','Pet','Party','PartyPet','Raid','RaidPet'} do
      CHH_SetConfigOption( 'panic'..panicType..unit, getglobal('CHH_PanicGeneralPanic'..panicType..unit) );
    end
  end

  CHH_InitTabs( CHH_Panic, CHH_PanicGeneral, 'PANIC', 'MISC', CHH_PanicInit, nil ); 

  CHH_PanicGeneralUnmapped:SetChecked( CH_Config.panicOnUnmapped );
  CHH_PanicGeneralPanicCure:SetChecked( CH_Config.panicCure );

  CHH_PanicGeneralPanicHealPlayer:Disable();		-- always heal yourself too (if not, change CH_NeediestHeal() !!!)

end

-- ========== PANIC BEHAVIOR =========================================================================================================================

function CHH_PanicBehaviorInit()

  CHH_InitTabs( CHH_Panic, CHH_PanicBehavior, 'PANIC', 'LAYOUT', CHH_PanicBehaviorInit, nil ); 

  UIDropDownMenu_Initialize( CHH_PanicBehaviorBehavior, CHH_PanicBehaviorBehaviorInit );

  CHH_PanicBehaviorClassClicked( gPanicBehaviorClass )

end

function CHH_PanicBehaviorBehaviorInit()

  local k, v;
  local info = {};

  for k,v in gPanicBehavior do
    info.checked = nil;
    info.text = v;
    if ( k == CH_Config.panicBehavior ) then 
      UIDropDownMenu_SetText( info.text, CHH_PanicBehaviorBehavior );
      info.checked = true;
    end
    info.func = CHH_PanicBehaviorBehaviorClicked;
    info.value = k;
    UIDropDownMenu_AddButton(info);
  end

end

function CHH_PanicBehaviorBehaviorClicked()

  CH_Config.panicBehavior = this.value;
  UIDropDownMenu_SetText( gPanicBehavior[this.value], CHH_PanicBehaviorBehavior );
  CHH_PanicBehaviorClassClicked( gPanicBehaviorClass )

end

function CHH_PanicBehaviorUpdateLine( objectName, label, class, min, max )

  local minTxt, maxTxt, k, v;
  local spellTxt = '';

  if ( min == nil ) then
    minTxt = 0;
  else
    minTxt = CH_EMERGENCY_STATE[min].Y[class];
  end
  maxTxt = CH_EMERGENCY_STATE[max].Y[class];

  getglobal('CHH_PanicBehaviorEmergency'..objectName..'Label'):SetText( string.format('%s (%d%% - %d%%)',label,minTxt,maxTxt) );
  
  for k,v in CH_EMERGENCY_SPELLS[CH_Config.panicBehavior][max][class] do
    if ( spellTxt ~= '' ) then
      spellTxt = spellTxt .. ', ';
    end
    if ( strsub(v,1,1) == '!' ) then
      spellTxt = spellTxt .. '|cFF'..CH_COLOR.YELLOW.html..CH_ACTION_TYPE_TEXT[strsub(v,2)]..'|r';
    else
      spellTxt = spellTxt .. CH_ACTION_TYPE_TEXT[v];
    end
  end

  getglobal('CHH_PanicBehaviorEmergency'..objectName..'SpellLabel'):SetText( spellTxt );

end

function CHH_PanicBehaviorClassClicked( class )

  getglobal('CHH_PanicBehavior'..gPanicBehaviorClass..'Label'):SetTextColor( CH_COLOR.WHITE.r, CH_COLOR.WHITE.g, CH_COLOR.WHITE.b );
  getglobal('CHH_PanicBehavior'..gPanicBehaviorClass..'Background'):Hide();
  
  gPanicBehaviorClass = class;

  CHH_PanicBehaviorUpdateLine( 'None',    CHT_LABEL_EMERGENCY_NONE,    class, CH_EMERGENCY_WOUNDED, CH_EMERGENCY_NONE );
  CHH_PanicBehaviorUpdateLine( 'Wounded', CHT_LABEL_EMERGENCY_WOUNDED, class, CH_EMERGENCY_FAIR,    CH_EMERGENCY_WOUNDED );
  CHH_PanicBehaviorUpdateLine( 'Fair',    CHT_LABEL_EMERGENCY_FAIR,    class, CH_EMERGENCY_POOR,    CH_EMERGENCY_FAIR );
  CHH_PanicBehaviorUpdateLine( 'Poor',    CHT_LABEL_EMERGENCY_POOR,    class, CH_EMERGENCY_CRITIC,  CH_EMERGENCY_POOR );
  CHH_PanicBehaviorUpdateLine( 'Critic',  CHT_LABEL_EMERGENCY_CRITIC,  class, nil,                  CH_EMERGENCY_CRITIC );

  getglobal('CHH_PanicBehavior'..gPanicBehaviorClass..'Label'):SetTextColor( CH_COLOR.GOLD.r, CH_COLOR.GOLD.g, CH_COLOR.GOLD.b );
  getglobal('CHH_PanicBehavior'..gPanicBehaviorClass..'Background'):Show();

  CHH_PanicBehaviorEmergencySpellClicked( CH_EMERGENCY_NONE );

end

function CHH_PanicBehaviorEmergencySpellClicked( emergency )

  local i, frame, spellFrame, forceFrame, spellType, isForced;

  frame = getglobal('CHH_PanicBehaviorEmergency'..gEmergencyMapping[gPanicBehaviorEmergency]..'SpellBackground'):Hide();
  frame = getglobal('CHH_PanicBehaviorEmergency'..gEmergencyMapping[emergency]..'SpellBackground'):Show();

  gPanicBehaviorEmergency = emergency;

  for i=1,4 do
    frame = getglobal( 'CHH_PanicBehaviorSpellEdit'..i );
    spellFrame = getglobal( 'CHH_PanicBehaviorSpellEdit'..i..'Spell' );
    forceFrame = getglobal( 'CHH_PanicBehaviorSpellEdit'..i..'ForceCast' );
    spellType = CH_EMERGENCY_SPELLS[CH_Config.panicBehavior][gPanicBehaviorEmergency][gPanicBehaviorClass][i];
    if ( spellType and strsub(spellType,1,1) == '!' ) then
      isForced = true;
      spellType = strsub( spellType, 2 );
    else
      isForced = false;
    end
    spellFrame:SetText( CH_ACTION_TYPE_TEXT[spellType] );
    forceFrame:SetChecked( isForced );
    forceFrame:Disable();
    frame:Show();
  end

end
