-- ==========================================================================================================================================================
-- Global definitions for ClickHeal. 
-- This file is loaded right after the localization is done, as it depends on local settings
-- ==========================================================================================================================================================

local i;

-- defines for all effects
CH_EFFECT_REGROWTH = 'G';
CH_EFFECT_REJUVENATION = 'J';
CH_EFFECT_RENEW = 'R';
CH_EFFECT_POWER_WORD_SHIELD = 'S';
CH_EFFECT_WEAKENED_SOUL = 'WS';
CH_EFFECT_RECENTLY_BANDAGED = 'B';
CH_EFFECT_MAGIC = 'M';
CH_EFFECT_CURSE = 'C';
CH_EFFECT_POISON = 'P';
CH_EFFECT_DISEASE = 'D';
CH_EFFECT_CHARM = 'H';
CH_EFFECT_TRACKING = 'T';
CH_EFFECT_PHASE_SHIFT = 'PS';

-- data for all effects
-- NOTE: CH_EFFECT_MISSING_BUFF is a dummy, which combines all missing buffs, only used in AffectsAsString()
CH_EFFECT_DATA = { 
  [CH_EFFECT_REGROWTH]          = {sign=CHT_EFFECT_REGROWTH_SIGN,         effectType='BUFF',    buffName=CH_SPELL_REGROWTH,           color='BRIGHTGREEN'},
  [CH_EFFECT_REJUVENATION]      = {sign=CHT_EFFECT_REJUVENATION_SIGN,     effectType='BUFF',    buffName=CH_SPELL_REJUVENATION,       color='BRIGHTGREEN'},
  [CH_EFFECT_RENEW]             = {sign=CHT_EFFECT_RENEW_SIGN,            effectType='BUFF',    buffName=CH_SPELL_RENEW,              color='BRIGHTGREEN'},
  [CH_EFFECT_POWER_WORD_SHIELD] = {sign=CHT_EFFECT_POWER_WORD_SHIELD_SIGN,effectType='BUFF',    buffName=CH_SPELL_POWER_WORD_SHIELD,  color='BRIGHTGREEN'},
  [CH_EFFECT_WEAKENED_SOUL]     = {sign=CHT_EFFECT_WEAKENED_SOUL_SIGN,    effectType='DEBUFF',  buffName=CH_DEBUFF_WEAKENED_SOUL,     color='ORANGE'},
  [CH_EFFECT_RECENTLY_BANDAGED] = {sign=CHT_EFFECT_RECENTLY_BANDAGED_SIGN,effectType='DEBUFF',  buffName=CH_DEBUFF_RECENTLY_BANDAGED, color='ORANGE'},
  [CH_EFFECT_MAGIC]             = {sign=CHT_EFFECT_MAGIC_SIGN,            effectType='DEBUFF',  buffName=CH_DEBUFF_TYPE_MAGIC,        color='RED'},
  [CH_EFFECT_CURSE]             = {sign=CHT_EFFECT_CURSE_SIGN,            effectType='DEBUFF',  buffName=CH_DEBUFF_TYPE_CURSE,        color='RED'},
  [CH_EFFECT_POISON]            = {sign=CHT_EFFECT_POISON_SIGN,           effectType='DEBUFF',  buffName=CH_DEBUFF_TYPE_POISON,       color='RED'},
  [CH_EFFECT_DISEASE]           = {sign=CHT_EFFECT_DISEASE_SIGN,          effectType='DEBUFF',  buffName=CH_DEBUFF_TYPE_DISEASE,      color='RED'},
  [CH_EFFECT_CHARM]             = {sign=CHT_EFFECT_CHARM_SIGN,            effectType='DEBUFF',  buffName=CH_DEBUFF_TYPE_CHARM,        color='RED'},
  [CH_EFFECT_TRACKING]          = {sign=CHT_EFFECT_TRACKING_SIGN,         effectType='TRACKING',buffName=nil,                         color='YELLOW'},
  [CH_EFFECT_PHASE_SHIFT]       = {sign=CHT_EFFECT_PHASE_SHIFT,           effectType='BUFF',    buffName=CH_PETSPELL_PHASE_SHIFT,     color='ORANGE'},
};

CH_EFFECT_DATA[CH_EFFECT_MAGIC].curableBy =   {PRIEST=1,};
CH_EFFECT_DATA[CH_EFFECT_CURSE].curableBy =   {DRUID=1,MAGE=1,};
CH_EFFECT_DATA[CH_EFFECT_POISON].curableBy =  {DRUID=1,PALADIN=1,SHAMAN=1,};
CH_EFFECT_DATA[CH_EFFECT_DISEASE].curableBy = {PALADIN=1,SHAMAN=1,PRIEST=1,};

-- mapping of buff/debuff name to mapping index
CH_EFFECT_MAP = {};
for i,_ in CH_EFFECT_DATA do
  if ( CH_EFFECT_DATA[i].buffName ) then
    CH_EFFECT_MAP[CH_EFFECT_DATA[i].buffName] = i;
  end
end

-- ordered array to loop over when displaying party buffs/debuffs (in PANIC button)
CH_EFFECT_DISPLAY_PARTY = { CH_EFFECT_CURSE, CH_EFFECT_MAGIC, CH_EFFECT_POISON, CH_EFFECT_DISEASE, CH_EFFECT_CHARM };

-- ordered array to loop over when displaying single unit buffs/debuffs
CH_EFFECT_DISPLAY_UNIT  = { CH_EFFECT_CURSE, CH_EFFECT_MAGIC, CH_EFFECT_POISON, CH_EFFECT_DISEASE, CH_EFFECT_CHARM,
                            CH_EFFECT_WEAKENED_SOUL, CH_EFFECT_RECENTLY_BANDAGED,
                            CH_EFFECT_REGROWTH, CH_EFFECT_REJUVENATION, CH_EFFECT_RENEW, CH_EFFECT_POWER_WORD_SHIELD,
		            CH_EFFECT_PHASE_SHIFT };

-- abbrevations all assignable mousebuttons
CH_MOUSE_BUTTONS_LABEL_ALL = {
      ['LeftButton']               = CHT_MOUSE_LEFT_BUTTON_LABEL,
      ['MiddleButton']             = CHT_MOUSE_MIDDLE_BUTTON_LABEL,
      ['RightButton']              = CHT_MOUSE_RIGHT_BUTTON_LABEL,
      ['Button4']                  = CHT_MOUSE_BUTTON4_LABEL,
      ['Button5']                  = CHT_MOUSE_BUTTON5_LABEL,
      ['ShiftLeftButton']          = CHT_MOUSE_SHIFT_LEFT_BUTTON_LABEL,
      ['ShiftMiddleButton']        = CHT_MOUSE_SHIFT_MIDDLE_BUTTON_LABEL,
      ['ShiftRightButton']         = CHT_MOUSE_SHIFT_RIGHT_BUTTON_LABEL,
      ['ShiftButton4']             = CHT_MOUSE_SHIFT_BUTTON4_LABEL,
      ['ShiftButton5']             = CHT_MOUSE_SHIFT_BUTTON5_LABEL,
      ['CtrlLeftButton']           = CHT_MOUSE_CTRL_LEFT_BUTTON_LABEL,
      ['CtrlMiddleButton']         = CHT_MOUSE_CTRL_MIDDLE_BUTTON_LABEL,
      ['CtrlRightButton']          = CHT_MOUSE_CTRL_RIGHT_BUTTON_LABEL,
      ['CtrlButton4']              = CHT_MOUSE_CTRL_BUTTON4_LABEL,
      ['CtrlButton5']              = CHT_MOUSE_CTRL_BUTTON5_LABEL,
      ['AltLeftButton']            = CHT_MOUSE_ALT_LEFT_BUTTON_LABEL,
      ['AltMiddleButton']          = CHT_MOUSE_ALT_MIDDLE_BUTTON_LABEL,
      ['AltRightButton']           = CHT_MOUSE_ALT_RIGHT_BUTTON_LABEL,
      ['AltButton4']               = CHT_MOUSE_ALT_BUTTON4_LABEL,
      ['AltButton5']               = CHT_MOUSE_ALT_BUTTON5_LABEL,
      ['ShiftCtrlLeftButton']      = CHT_MOUSE_SHIFT_CTRL_LEFT_BUTTON_LABEL,
      ['ShiftCtrlMiddleButton']    = CHT_MOUSE_SHIFT_CTRL_MIDDLE_BUTTON_LABEL,
      ['ShiftCtrlRightButton']     = CHT_MOUSE_SHIFT_CTRL_RIGHT_BUTTON_LABEL,
      ['ShiftCtrlButton4']         = CHT_MOUSE_SHIFT_CTRL_BUTTON4_LABEL,
      ['ShiftCtrlButton5']         = CHT_MOUSE_SHIFT_CTRL_BUTTON5_LABEL,
      ['ShiftAltLeftButton']       = CHT_MOUSE_SHIFT_ALT_LEFT_BUTTON_LABEL,
      ['ShiftAltMiddleButton']     = CHT_MOUSE_SHIFT_ALT_MIDDLE_BUTTON_LABEL,
      ['ShiftAltRightButton']      = CHT_MOUSE_SHIFT_ALT_RIGHT_BUTTON_LABEL,
      ['ShiftAltButton4']          = CHT_MOUSE_SHIFT_ALT_BUTTON4_LABEL,
      ['ShiftAltButton5']          = CHT_MOUSE_SHIFT_ALT_BUTTON5_LABEL,
      ['CtrlAltLeftButton']        = CHT_MOUSE_CTRL_ALT_LEFT_BUTTON_LABEL,
      ['CtrlAltMiddleButton']      = CHT_MOUSE_CTRL_ALT_MIDDLE_BUTTON_LABEL,
      ['CtrlAltRightButton']       = CHT_MOUSE_CTRL_ALT_RIGHT_BUTTON_LABEL,
      ['CtrlAltButton4']           = CHT_MOUSE_CTRL_ALT_BUTTON4_LABEL,
      ['CtrlAltButton5']           = CHT_MOUSE_CTRL_ALT_BUTTON5_LABEL,
      ['ShiftCtrlAltLeftButton']   = CHT_MOUSE_SHIFT_CTRL_ALT_LEFT_BUTTON_LABEL,
      ['ShiftCtrlAltMiddleButton'] = CHT_MOUSE_SHIFT_CTRL_ALT_MIDDLE_BUTTON_LABEL,
      ['ShiftCtrlAltRightButton']  = CHT_MOUSE_SHIFT_CTRL_ALT_RIGHT_BUTTON_LABEL,
      ['ShiftCtrlAltButton4']      = CHT_MOUSE_SHIFT_CTRL_ALT_BUTTON4_LABEL,
      ['ShiftCtrlAltButton5']      = CHT_MOUSE_SHIFT_CTRL_ALT_BUTTON5_LABEL,
    };

-- abbrevations all assignable mousebuttons
CH_MOUSE_BUTTONS_ABBR_ALL = {
      ['LeftButton']               = CHT_MOUSE_LEFT_BUTTON_ABBR,
      ['MiddleButton']             = CHT_MOUSE_MIDDLE_BUTTON_ABBR,
      ['RightButton']              = CHT_MOUSE_RIGHT_BUTTON_ABBR,
      ['Button4']                  = CHT_MOUSE_BUTTON4_ABBR,
      ['Button5']                  = CHT_MOUSE_BUTTON5_ABBR,
      ['ShiftLeftButton']          = CHT_MOUSE_SHIFT_LEFT_BUTTON_ABBR,
      ['ShiftMiddleButton']        = CHT_MOUSE_SHIFT_MIDDLE_BUTTON_ABBR,
      ['ShiftRightButton']         = CHT_MOUSE_SHIFT_RIGHT_BUTTON_ABBR,
      ['ShiftButton4']             = CHT_MOUSE_SHIFT_BUTTON4_ABBR,
      ['ShiftButton5']             = CHT_MOUSE_SHIFT_BUTTON5_ABBR,
      ['CtrlLeftButton']           = CHT_MOUSE_CTRL_LEFT_BUTTON_ABBR,
      ['CtrlMiddleButton']         = CHT_MOUSE_CTRL_MIDDLE_BUTTON_ABBR,
      ['CtrlRightButton']          = CHT_MOUSE_CTRL_RIGHT_BUTTON_ABBR,
      ['CtrlButton4']              = CHT_MOUSE_CTRL_BUTTON4_ABBR,
      ['CtrlButton5']              = CHT_MOUSE_CTRL_BUTTON5_ABBR,
      ['AltLeftButton']            = CHT_MOUSE_ALT_LEFT_BUTTON_ABBR,
      ['AltMiddleButton']          = CHT_MOUSE_ALT_MIDDLE_BUTTON_ABBR,
      ['AltRightButton']           = CHT_MOUSE_ALT_RIGHT_BUTTON_ABBR,
      ['AltButton4']               = CHT_MOUSE_ALT_BUTTON4_ABBR,
      ['AltButton5']               = CHT_MOUSE_ALT_BUTTON5_ABBR,
      ['ShiftCtrlLeftButton']      = CHT_MOUSE_SHIFT_CTRL_LEFT_BUTTON_ABBR,
      ['ShiftCtrlMiddleButton']    = CHT_MOUSE_SHIFT_CTRL_MIDDLE_BUTTON_ABBR,
      ['ShiftCtrlRightButton']     = CHT_MOUSE_SHIFT_CTRL_RIGHT_BUTTON_ABBR,
      ['ShiftCtrlButton4']         = CHT_MOUSE_SHIFT_CTRL_BUTTON4_ABBR,
      ['ShiftCtrlButton5']         = CHT_MOUSE_SHIFT_CTRL_BUTTON5_ABBR,
      ['ShiftAltLeftButton']       = CHT_MOUSE_SHIFT_ALT_LEFT_BUTTON_ABBR,
      ['ShiftAltMiddleButton']     = CHT_MOUSE_SHIFT_ALT_MIDDLE_BUTTON_ABBR,
      ['ShiftAltRightButton']      = CHT_MOUSE_SHIFT_ALT_RIGHT_BUTTON_ABBR,
      ['ShiftAltButton4']          = CHT_MOUSE_SHIFT_ALT_BUTTON4_ABBR,
      ['ShiftAltButton5']          = CHT_MOUSE_SHIFT_ALT_BUTTON5_ABBR,
      ['CtrlAltLeftButton']        = CHT_MOUSE_CTRL_ALT_LEFT_BUTTON_ABBR,
      ['CtrlAltMiddleButton']      = CHT_MOUSE_CTRL_ALT_MIDDLE_BUTTON_ABBR,
      ['CtrlAltRightButton']       = CHT_MOUSE_CTRL_ALT_RIGHT_BUTTON_ABBR,
      ['CtrlAltButton4']           = CHT_MOUSE_CTRL_ALT_BUTTON4_ABBR,
      ['CtrlAltButton5']           = CHT_MOUSE_CTRL_ALT_BUTTON5_ABBR,
      ['ShiftCtrlAltLeftButton']   = CHT_MOUSE_SHIFT_CTRL_ALT_LEFT_BUTTON_ABBR,
      ['ShiftCtrlAltMiddleButton'] = CHT_MOUSE_SHIFT_CTRL_ALT_MIDDLE_BUTTON_ABBR,
      ['ShiftCtrlAltRightButton']  = CHT_MOUSE_SHIFT_CTRL_ALT_RIGHT_BUTTON_ABBR,
      ['ShiftCtrlAltButton4']      = CHT_MOUSE_SHIFT_CTRL_ALT_BUTTON4_ABBR,
      ['ShiftCtrlAltButton5']      = CHT_MOUSE_SHIFT_CTRL_ALT_BUTTON5_ABBR,
    };

-- mesmerization info
CH_MESMERIZE_INFO = { [CH_SPELL_SHACKLE_UNDEAD]   = {pattern  = "undefined",
                                                     texture  = "Interface/Icons/Spell_Nature_Slow",
                                                     duration = {[1]=30,[2]=40,[3]=50,MAX=50},
                                                    },
                      [CH_SPELL_POLYMORPH]        = {pattern  = "undefined",
                                                     texture  = "Interface/Icons/Spell_Nature_Polymorph",
                                                     duration = {[1]=20,[2]=30,[3]=40,[4]=50,MAX=50},
                                                    },
                      [CH_SPELL_ENTANGLING_ROOTS] = {pattern  = "undefined",
                                                     texture  = "Interface/Icons/Spell_Nature_StrangleVines",
                                                     duration = {[1]=12,[2]=15,[3]=18,[4]=21,[5]=24,[6]=27,MAX=27},
                                                    },
                      [CH_SPELL_HIBERNATE]        = {pattern  = "undefined",
                                                     texture  = "Interface/Icons/Spell_Nature_Sleep",
                                                     duration = {[1]=20,[2]=30,[3]=40,MAX=40},
                                                    },
                      [CH_SPELL_BANISH]           = {pattern  = "undefined",
                                                     texture  = "Interface/Icons/Spell_Shadow_Cripple",
                                                     duration = {[1]=20,[2]=30,MAX=30},
                                                    },
                    };

-- class info, dependant on locale
CH_CLASS_INFO['DRUID'].shapeshift   = {forms={CASTER=CH_LABEL_SHAPESHIFT_CASTER,BEAR=CH_LABEL_SHAPESHIFT_BEAR,CAT=CH_LABEL_SHAPESHIFT_CAT},
                                       default='CASTER'
                                      };
CH_CLASS_INFO['HUNTER'].shapeshift  = {forms={RANGE=CH_LABEL_SHAPESHIFT_RANGE,MELEE=CH_LABEL_SHAPESHIFT_MELEE},
                                       default='RANGE'
                                      };
CH_CLASS_INFO['ROGUE'].shapeshift   = {forms={STEALTH=CH_LABEL_SHAPESHIFT_STEALTH,MELEE=CH_LABEL_SHAPESHIFT_MELEE},
                                       default='MELEE'
                                      };
CH_CLASS_INFO['WARRIOR'].shapeshift = {forms={BAT=CH_LABEL_SHAPESHIFT_BATTLE_STANCE,DEF=CH_LABEL_SHAPESHIFT_DEFENSIVE_STANCE,BER=CH_LABEL_SHAPESHIFT_BERSERKER_STANCE},
                                       default='BAT'
                                      };

-- default configuration settings
  CH_DefaultConfig = { 
   CTRAEnabled                      = {tab='CONFIG',  group='MISC',        value=true,    hint=CHT_HINT_CTRA_ENABLED},
   DUFEnabled                       = {tab='CONFIG',  group='MISC',        value=true,    hint=CHT_HINT_DUF_ENABLED},
   PCUFEnabled                      = {tab='CONFIG',  group='MISC',        value=true,    hint=CHT_HINT_PCUF_ENABLED},
   WoWGuiEnabled                    = {tab='CONFIG',  group='MISC',        value=false,   hint=CHT_HINT_WOW_GUI_ENABLED},
   DcrEnabled                       = {tab='CONFIG',  group='MISC',        value=true,    hint=CHT_HINT_DCR_ENABLED},
   NeedyListEnabled                 = {tab='CONFIG',  group='MISC',        value=true,    hint=CHT_HINT_NEEDYLIST_ENABLED},
   castSpellByNameOnSelf            = {tab='CONFIG',  group='MISC',        value=true,    hint=CHT_HINT_CAST_SPELL_BY_NAME_ON_SELF},
   showBagCooldown                  = {tab='CONFIG',  group='COOLDOWN',    value=true,    hint=CHT_HINT_SHOW_BAG_COOLDOWN},
   includeEquipHealBonus            = {tab='CONFIG',  group='OVERHEAL',    value=true,    hint=CHT_HINT_INCLUDE_EQUIP_HEAL_BONUS},
   playerHitSound                   = {tab='CONFIG',  group='NOTIFY',      value=true,    hint=CHT_HINT_PLAYER_HIT_SOUND},
   playerHitSoundDelay              = {tab='CONFIG',  group='NOTIFY',      value=10,      hint=CHT_HINT_PLAYER_HIT_SOUND_DELAY},
   announceHitToParty               = {tab='CONFIG',  group='NOTIFY',      value=false,   hint=CHT_HINT_ANNOUNCE_HIT_TO_PARTY},
   announceHitToPartyHP             = {tab='CONFIG',  group='NOTIFY',      value=80,      hint=CHT_HINT_ANNOUNCE_HIT_TO_PARTY_HP},
   announceHitToPartyHPFade         = {tab='CONFIG',  group='NOTIFY',      value=90,      hint=CHT_HINT_ANNOUNCE_HIT_TO_PARTY_HP_FADE},
   announceHitToPartyDelay          = {tab='CONFIG',  group='NOTIFY',      value=15,      hint=CHT_HINT_ANNOUNCE_HIT_TO_PARTY_DELAY},
   announceHitToPartyMsg            = {tab='CONFIG',  group='NOTIFY',      value=CHT_ANNOUNCE_HIT_TO_PARTY_MSG,hint=CHT_HINT_ANNOUNCE_HIT_TO_PARTY_MSG},
   announceOOMToParty               = {tab='CONFIG',  group='NOTIFY',      value=false,   hint=CHT_HINT_ANNOUNCE_OOM_TO_PARTY},
   announceOOMToPartyMana           = {tab='CONFIG',  group='NOTIFY',      value=20,      hint=CHT_HINT_ANNOUNCE_OOM_TO_PARTY_MANA},
   announceOOMToPartyDelay          = {tab='CONFIG',  group='NOTIFY',      value=15,      hint=CHT_HINT_ANNOUNCE_OOM_TO_PARTY_DELAY},
   safeTaunt                        = {tab='CONFIG',  group='COMBAT',      value=true,    hint=CHT_HINT_COMBAT_SAFE_TAUNT},
   selfDefenseAttackTarget          = {tab='CONFIG',  group='COMBAT',      value=false,   hint=CHT_HINT_SELF_DEFENSE_ATTACK_TARGET},
   selfDefensePetAttackTarget       = {tab='CONFIG',  group='COMBAT',      value=true,    hint=CHT_HINT_SELF_DEFENSE_PET_ATTACK_TARGET},
   selfDefenseNoMesmerize           = {tab='CONFIG',  group='COMBAT',      value=true,    hint=CHT_HINT_SELF_DEFENSE_NO_MESMERIZE},
   selfDefenseDirectAttack          = {tab='CONFIG',  group='COMBAT',      value=true,    hint=CHT_HINT_SELF_DEFENSE_DIRECT_ATTACK},
   selfDefenseNotInParty            = {tab='CONFIG',  group='COMBAT',      value=true,    hint=CHT_HINT_SELF_DEFENSE_NOT_IN_PARTY},

   showClickHeal                    = {tab='GUI',     group='MISC',        value=true,    hint=CHT_HINT_SHOW_CLICKHEAL},
   showParty                        = {tab='GUI',     group='MISC',        value=true,    hint=CHT_HINT_SHOW_PARTY},
   showPartyPets                    = {tab='GUI',     group='MISC',        value=true,    hint=CHT_HINT_SHOW_PARTY_PETS},
   showWoWParty                     = {tab='GUI',     group='MISC',        value=true,    hint=CHT_HINT_SHOW_WOW_PARTY},
   showPlayerMana                   = {tab='GUI',     group='MISC',        value=false,   hint=CHT_HINT_SHOW_PLAYER_MANA},
   showPetFocus                     = {tab='GUI',     group='MISC',        value=true,    hint=CHT_HINT_SHOW_PET_FOCUS},
   showPartyPetTarget               = {tab='GUI',     group='MISC',        value=true,    hint=CHT_HINT_SHOW_PARTY_PET_TARGET},
   showMesmerize                    = {tab='GUI',     group='MISC',        value=true,    hint=CHT_HINT_SHOW_MESMERIZE},
   showHints                        = {tab='GUI',     group='MISC',        value=true,    hint=CHT_HINT_SHOW_HINTS},
   updateEffectsInterval            = {tab='GUI',     group='MISC',        value=0.1,     hint=CHT_HINT_UPDATE_EFFECTS_INTERVAL},
   showFiveSecondRule               = {tab='GUI',     group='MISC',        value=true,    hint=CHT_HINT_SHOW_FIVE_SECOND_RULE},
   showAnchors                      = {tab='GUI',     group='MISC',        value=true,    hint=CHT_HINT_SHOW_ANCHORS},
   frameGroupMode                   = {tab='GUI',     group='MISC',        value="ALL",   hint=CHT_HINT_FRAME_GROUP_MODE},
   showRaidGroup1                   = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_GROUP1},
   showRaidGroup2                   = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_GROUP2},
   showRaidGroup3                   = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_GROUP3},
   showRaidGroup4                   = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_GROUP4},
   showRaidGroup5                   = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_GROUP5},
   showRaidGroup6                   = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_GROUP6},
   showRaidGroup7                   = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_GROUP7},
   showRaidGroup8                   = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_GROUP8},
   showRaidClassDRUID               = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_CLASS_DRUID},
   showRaidClassHUNTER              = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_CLASS_HUNTER},
   showRaidClassMAGE                = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_CLASS_MAGE},
   showRaidClassPALADIN             = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_CLASS_PALADIN},
   showRaidClassPRIEST              = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_CLASS_PRIEST},
   showRaidClassROGUE               = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_CLASS_ROGUE},
   showRaidClassSHAMAN              = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_CLASS_SHAMAN},
   showRaidClassWARLOCK             = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_CLASS_WARLOCK},
   showRaidClassWARRIOR             = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_CLASS_WARRIOR},
   showRaidPets                     = {tab='GUI',     group='RAID',        value=false,   hint=CHT_HINT_SHOW_RAID_PETS},
   raidPetsScanInterval             = {tab='GUI',     group='RAID',        value=5,       hint=CHT_HINT_RAID_PETS_SCAN_INTERVAL},
   raidGroupFrameWidth              = {tab='GUI',     group='RAID',        value=100,     hint=CHT_HINT_RAID_GROUP_FRAME_WIDTH},
   raidGroupFrameHeight             = {tab='GUI',     group='RAID',        value=32,      hint=CHT_HINT_RAID_GROUP_FRAME_HEIGTH},
   raidClassFrameWidth              = {tab='GUI',     group='RAID',        value=100,     hint=CHT_HINT_RAID_CLASS_FRAME_WIDTH},
   raidClassFrameHeight             = {tab='GUI',     group='RAID',        value=32,      hint=CHT_HINT_RAID_CLASS_FRAME_HEIGTH},
   raidGroupFrameScale              = {tab='GUI',     group='RAID',        value=100,     hint=CHT_HINT_RAID_GROUP_FRAME_SCALE},
   raidClassFrameScale              = {tab='GUI',     group='RAID',        value=100,     hint=CHT_HINT_RAID_CLASS_FRAME_SCALE},
   frameAlign                       = {tab='GUI',     group='MAIN_FRAME',  value='CENTER',hint=CHT_HINT_FRAME_ALIGN},
   extraFrameWidth                  = {tab='GUI',     group='MAIN_FRAME',  value=50,      hint=CHT_HINT_EXTRA_FRAME_WIDTH},
   extraFrameHeight                 = {tab='GUI',     group='MAIN_FRAME',  value=24,      hint=CHT_HINT_EXTRA_FRAME_HEIGHT},
   panicFrameWidth                  = {tab='GUI',     group='MAIN_FRAME',  value=100,     hint=CHT_HINT_PANIC_FRAME_WIDTH},
   panicFrameHeight                 = {tab='GUI',     group='MAIN_FRAME',  value=32,      hint=CHT_HINT_PANIC_FRAME_HEIGHT},
   playerFrameWidth                 = {tab='GUI',     group='MAIN_FRAME',  value=100,     hint=CHT_HINT_PLAYER_FRAME_WIDTH},
   playerFrameHeight                = {tab='GUI',     group='MAIN_FRAME',  value=32,      hint=CHT_HINT_PLAYER_FRAME_HEIGHT},
   partyFrameWidth                  = {tab='GUI',     group='MAIN_FRAME',  value=100,     hint=CHT_HINT_PARTY_FRAME_WIDTH},
   partyFrameHeight                 = {tab='GUI',     group='MAIN_FRAME',  value=32,      hint=CHT_HINT_PARTY_FRAME_HEIGHT},
   petFrameWidth                    = {tab='GUI',     group='MAIN_FRAME',  value=100,     hint=CHT_HINT_PET_FRAME_WIDTH},
   petFrameHeight                   = {tab='GUI',     group='MAIN_FRAME',  value=32,      hint=CHT_HINT_PET_FRAME_HEIGHT},
   partyPetFrameWidth               = {tab='GUI',     group='MAIN_FRAME',  value=100,     hint=CHT_HINT_PARTYPET_FRAME_WIDTH},
   partyPetFrameHeight              = {tab='GUI',     group='MAIN_FRAME',  value=32,      hint=CHT_HINT_PARTYPET_FRAME_HEIGHT},
   extraFrameScale                  = {tab='GUI',     group='MAIN_FRAME',  value=100,     hint=CHT_HINT_EXTRA_FRAME_SCALE},
   panicFrameScale                  = {tab='GUI',     group='MAIN_FRAME',  value=100,     hint=CHT_HINT_PANIC_FRAME_SCALE},
   playerFrameScale                 = {tab='GUI',     group='MAIN_FRAME',  value=100,     hint=CHT_HINT_PLAYER_FRAME_SCALE},
   partyFrameScale                  = {tab='GUI',     group='MAIN_FRAME',  value=100,     hint=CHT_HINT_PARTY_FRAME_SCALE},
   petFrameScale                    = {tab='GUI',     group='MAIN_FRAME',  value=100,     hint=CHT_HINT_PET_FRAME_SCALE},
   partyPetFrameScale               = {tab='GUI',     group='MAIN_FRAME',  value=100,     hint=CHT_HINT_PARTYPET_FRAME_SCALE},
   dockTarget                       = {tab='GUI',     group='TARGET_FRAME',value='RIGHT', hint=CHT_HINT_DOCK_TARGET},
   colorTarget                      = {tab='GUI',     group='TARGET_FRAME',value='PLAYER',hint=CHT_HINT_COLOR_TARGET},
   showTargetDebuffs                = {tab='GUI',     group='TARGET_FRAME',value='ENEMY_CASTABLE',hint=CHT_HINT_SHOW_TARGET_DEBUFFS},
   playerTargetFrameWidth           = {tab='GUI',     group='TARGET_FRAME',value=90,      hint=CHT_HINT_PLAYER_TARGET_FRAME_WIDTH},
   playerTargetFrameHeight          = {tab='GUI',     group='TARGET_FRAME',value=32,      hint=CHT_HINT_PLAYER_TARGET_FRAME_HEIGHT},
   partyTargetFrameWidth            = {tab='GUI',     group='TARGET_FRAME',value=90,      hint=CHT_HINT_PARTY_TARGET_FRAME_WIDTH},
   partyTargetFrameHeight           = {tab='GUI',     group='TARGET_FRAME',value=32,      hint=CHT_HINT_PARTY_TARGET_FRAME_HEIGHT},
   petTargetFrameWidth              = {tab='GUI',     group='TARGET_FRAME',value=90,      hint=CHT_HINT_PET_TARGET_FRAME_WIDTH},
   petTargetFrameHeight             = {tab='GUI',     group='TARGET_FRAME',value=32,      hint=CHT_HINT_PET_TARGET_FRAME_HEIGHT},
   partyPetTargetFrameWidth         = {tab='GUI',     group='TARGET_FRAME',value=90,      hint=CHT_HINT_PARTYPET_TARGET_FRAME_WIDTH},
   partyPetTargetFrameHeight        = {tab='GUI',     group='TARGET_FRAME',value=32,      hint=CHT_HINT_PARTYPET_TARGET_FRAME_HEIGHT},
   playerTargetFrameScale           = {tab='GUI',     group='TARGET_FRAME',value=100,     hint=CHT_HINT_PLAYER_TARGET_FRAME_SCALE},
   partyTargetFrameScale            = {tab='GUI',     group='TARGET_FRAME',value=100,     hint=CHT_HINT_PARTY_TARGET_FRAME_SCALE},
   petTargetFrameScale              = {tab='GUI',     group='TARGET_FRAME',value=100,     hint=CHT_HINT_PET_TARGET_FRAME_SCALE},
   partyPetTargetFrameScale         = {tab='GUI',     group='TARGET_FRAME',value=100,     hint=CHT_HINT_PARTYPET_TARGET_FRAME_SCALE},
   unitTooltipInfo                  = {tab='GUI',     group='TOOLTIP',     value='ALWAYS',hint=CHT_HINT_UNIT_TOOLTIP_INFO},
   raidTooltipInfo                  = {tab='GUI',     group='TOOLTIP',     value='TOP',   hint=CHT_HINT_RAID_TOOLTIP_INFO},
   actionsTooltipInfo               = {tab='GUI',     group='TOOLTIP',     value='ALWAYS',hint=CHT_HINT_ACTIONS_TOOLTIP_INFO},
   actionsTooltipShowSpellRank      = {tab='GUI',     group='TOOLTIP',     value=true,    hint=CHT_HINT_ACTIONS_TOOLTIP_SHOW_SPELL_RANK},
   actionsTooltipSpellRankShowMax   = {tab='GUI',     group='TOOLTIP',     value=false,   hint=CHT_HINT_ACTIONS_TOOLTIP_SPELL_RANK_SHOW_MAX},

   finetunePwS                      = {tab='FRIEND',  group='MISC',        value=true,    hint=CHT_HINT_FINETUNE_PWS},
   finetuneRenew                    = {tab='FRIEND',  group='MISC',        value=true,    hint=CHT_HINT_FINETUNE_RENEW},
   finetuneRegrowth                 = {tab='FRIEND',  group='MISC',        value=true,    hint=CHT_HINT_FINETUNE_REGROWTH},
   finetuneRejuvenation             = {tab='FRIEND',  group='MISC',        value=true,    hint=CHT_HINT_FINETUNE_REJUVENATION},
   adjustSpellRank                  = {tab='FRIEND',  group='MISC',        value=true,    hint=CHT_HINT_ADJUST_SPELL_RANK},
   toggleShadowform                 = {tab='FRIEND',  group='MISC',        value=true,    hint=CHT_HINT_TOGGLE_SHADOWFORM},
   showFriendMana                   = {tab='FRIEND',  group='MISC',        value=false,   hint=CHT_HINT_SHOW_FRIEND_MANA},
   showFriendRage                   = {tab='FRIEND',  group='MISC',        value=false,   hint=CHT_HINT_SHOW_FRIEND_RAGE},
   showFriendEnergy                 = {tab='FRIEND',  group='MISC',        value=false,   hint=CHT_HINT_SHOW_FRIEND_ENERGY},
   showFriendFocus                  = {tab='FRIEND',  group='MISC',        value=false,   hint=CHT_HINT_SHOW_FRIEND_FOCUS},
   resurrectPlayer                  = {tab='FRIEND',  group='MISC',        value='AFTER_COMBAT',hint=CHT_HINT_RESURRECT_PLAYER},
   friendHPLabel                    = {tab='FRIEND',  group='MISC',        value='PERCENT_SIGN',hint=CHT_HINT_FRIEND_HP_LABEL},
   friendFrameBackground            = {tab='FRIEND',  group='MISC',        value='HEALTH',hint=CHT_HINT_FRIEND_FRAME_BACKGROUND},
   partyLabel                       = {tab='FRIEND',  group='MISC',        value='CLASS', hint=CHT_HINT_PARTY_LABEL},
   showFriendDebuffs                = {tab='FRIEND',  group='MISC',        value='ALL',   hint=CHT_HINT_SHOW_FRIEND_DEBUFFS},

   targetingMode                    = {tab='ENEMY',   group='MISC',        value='INT',   hint=CHT_HINT_TARGETING_MODE},
   showLevelDiff                    = {tab='EMENY',   group='MISC',        value=true,    hint=CHT_HINT_SHOW_LEVEL_DIFF},
   showEnemyMana                    = {tab='ENEMY',   group='MISC',        value=true,    hint=CHT_HINT_SHOW_ENEMY_MANA},
   showEnemyRage                    = {tab='ENEMY',   group='MISC',        value=true,    hint=CHT_HINT_SHOW_ENEMY_RAGE},
   showEnemyEnergy                  = {tab='ENEMY',   group='MISC',        value=true,    hint=CHT_HINT_SHOW_ENEMY_ENERGY},
   showEnemyFocus                   = {tab='ENEMY',   group='MISC',        value=true,    hint=CHT_HINT_SHOW_ENEMY_FOCUS},

   panicOnUnmapped                  = {tab='PANIC',   group='MISC',        value=true,    hint=CHT_HINT_PANIC_ON_UNMAPPED},
   panicHealPlayer                  = {tab='PANIC',   group='MISC',        value=true,    hint=CHT_HINT_PANIC_HEAL_PLAYER},
   panicHealPet                     = {tab='PANIC',   group='MISC',        value=true,    hint=CHT_HINT_PANIC_HEAL_PET},
   panicHealParty                   = {tab='PANIC',   group='MISC',        value=true,    hint=CHT_HINT_PANIC_HEAL_PARTY},
   panicHealPartyPet                = {tab='PANIC',   group='MISC',        value=true,    hint=CHT_HINT_PANIC_HEAL_PARTY_PET},
   panicHealRaid                    = {tab='PANIC',   group='MISC',        value=false,   hint=CHT_HINT_PANIC_HEAL_RAID},
   panicHealRaidPet                 = {tab='PANIC',   group='MISC',        value=false,   hint=CHT_HINT_PANIC_HEAL_RAID_PET},
   panicBuffPlayer                  = {tab='PANIC',   group='MISC',        value=true,    hint=CHT_HINT_PANIC_BUFF_PLAYER},
   panicBuffPet                     = {tab='PANIC',   group='MISC',        value=true,    hint=CHT_HINT_PANIC_BUFF_PET},
   panicBuffParty                   = {tab='PANIC',   group='MISC',        value=true,    hint=CHT_HINT_PANIC_BUFF_PARTY},
   panicBuffPartyPet                = {tab='PANIC',   group='MISC',        value=true,    hint=CHT_HINT_PANIC_BUFF_PARTY_PET},
   panicBuffRaid                    = {tab='PANIC',   group='MISC',        value=false,   hint=CHT_HINT_PANIC_BUFF_RAID},
   panicBuffRaidPet                 = {tab='PANIC',   group='MISC',        value=false,   hint=CHT_HINT_PANIC_BUFF_RAID_PET},
   panicCure                        = {tab='PANIC',   group='MISC',        value=true,    hint=CHT_HINT_PANIC_CURE},
   panicBehavior                    = {tab='PANIC',   group='BEHAVIOR',    value='FULL',  hint=CHT_HINT_PANIC_BEHAVIOR},

   buffPlayExpireSound              = {tab='BUFF',    group='MISC',        value=true,    hint=CHT_HINT_BUFF_PLAY_EXPIRE_SOUND},
   buffShowExpireMsg                = {tab='BUFF',    group='MISC',        value=true,    hint=CHT_HINT_BUFF_SHOW_EXPIRE_MSG},
   buffPlayWarnSound                = {tab='BUFF',    group='MISC',        value=true,    hint=CHT_HINT_BUFF_PLAY_WARN_SOUND},
   buffShowWarnMsg                  = {tab='BUFF',    group='MISC',        value=true,    hint=CHT_HINT_BUFF_SHOW_WARN_MSG},
   warnTrackingBuff                 = {tab='BUFF',    group='MISC',        value=true,    hint=CHT_HINT_WARN_TRACKING_BUFF},
   showRaidEffects                  = {tab='BUFF',    group='MISC',        value=true,    hint=CHT_HINT_SHOW_RAID_EFFECTS},
   combineMissingBuffsInPanic       = {tab='BUFF',    group='MISC',        value=true,    hint=CHT_HINT_COMBINE_BUFFS_IN_PANIC},

   extra1Name                       = {tab='EXTRA1',  group='MISC',        value='Ex1',   hint=CHT_HINT_EXTRA1NAME},
   extra1Hidden                     = {tab='EXTRA1',  group='MISC',        value=false,   hint=CHT_HINT_EXTRA1HIDDEN},
   extra2Name                       = {tab='EXTRA2',  group='MISC',        value='Ex2',   hint=CHT_HINT_EXTRA2NAME},
   extra2Hidden                     = {tab='EXTRA2',  group='MISC',        value=false,   hint=CHT_HINT_EXTRA2HIDDEN},
   extra3Name                       = {tab='EXTRA3',  group='MISC',        value='Ex3',   hint=CHT_HINT_EXTRA3NAME},
   extra3Hidden                     = {tab='EXTRA3',  group='MISC',        value=false,   hint=CHT_HINT_EXTRA3HIDDEN},
   extra4Name                       = {tab='EXTRA4',  group='MISC',        value='Ex4',   hint=CHT_HINT_EXTRA4NAME},
   extra4Hidden                     = {tab='EXTRA4',  group='MISC',        value=false,   hint=CHT_HINT_EXTRA4HIDDEN},

   overheal                         = {tab='CONFIG',  group='OVERHEAL',    						-- below AND at !!! checkTime in milliesc
                                       value={ QUICK = { startBelow = 99, downgrade = true, combatDowngrade = false, baseOnPerc = 50, hotPerc = 50, modifyTotalPerc = 100,
                                                         dpsCheck = 5, clickAbortPerc = 101, lomDowngradeRanks = 0,
                                                       },
                                               SLOW  = { startBelow = 99, downgrade = true, combatDowngrade = false, baseOnPerc = 50, hotPerc = 50, modifyTotalPerc = 100,
                                                         dpsCheck = 5, clickAbortPerc = 101, lomDowngradeRanks = 0,
                                                       },
                                             },
                                       hint=CHT_HINT_OVERHEAL},

  partySort                         = {tab='GUI',     group='MISC',
                                       value={[1]='player',[2]='party1',[3]='party2',[4]='party3',[5]='party4',
                                              [6]='pet',[7]='partypet1',[8]='partypet2',[9]='partypet3',[10]='partypet4'},
                                       hint=CHT_HINT_PARTY_SORT},

  nameColor                         = {tab='ENEMY',   group='MISC',
                                       value={ playertarget = 'DEFAULT', party1target = 'DEFAULT', party2target = 'DEFAULT', party3target = 'DEFAULT', party4target = 'DEFAULT',
                                               pettarget = 'DEFAULT', partypet1target = 'DEFAULT', partypet2target = 'DEFAULT', partypet3target = 'DEFAULT', partypet4target = 'DEFAULT',
                                               SHIELD = 'DEFAULT', SELECTED = 'DEFAULT', FRIEND = 'DEFAULT'},
                                       hint=CHT_HINT_NAME_COLOR},

   notifySpellCast                  = {tab='CONFIG',  group='NOTIFY2',     
                                       value={},   
                                       PRIEST ={ [CH_SPELL_RESURRECTION]          ={say=true, party=true, raid=true, target=true, },
                                               },
                                       DRUID  ={ [CH_SPELL_REBIRTH]               ={say=true, party=true, raid=true, target=true, },
                                               },
                                       PALADIN={ [CH_SPELL_LAY_ON_HANDS]          ={say=nil,  party=true, raid=true, target=true, },
                                                [CH_SPELL_DIVINE_INTERVENTION]    ={say=nil,  party=true, raid=true, target=true, },
                                                [CH_SPELL_REDEMPTION]             ={say=true, party=true, raid=true, target=true, },
                                               },
                                       SHAMAN ={
                                                [CH_SPELL_ANCESTRAL_SPIRIT]       ={say=true, party=true, raid=true, target=true, },
                                               },
                                       hint=CHT_HINT_NOTIFY_SPELLCAST},
 };
